#include <linux/types.h>
#include <linux/time.h>
#include <linux/timer.h>
#include <linux/midi.h>

/*
 * This is where you configure the MPU401 devices.
 * Define NMIDI to be the number of MPU401 devices you have installed.
 * And add an entry to the midi_conf array describing each
 * device's I/O addr and IRQ number.
 */
#define NMIDI 1
int NumMidi = NMIDI;
struct midi_config midi_conf[NMIDI] =
    {{0x330, 9}};			/* 'standard' MPU401 */
struct midi_softc midi_sc[NMIDI];
